@@ -1,6 +1,5 @@
-# This file was created automatically by SWIG.
+# This file was created automatically by SWIG 1.3.27.
 # Don't modify this file, modify the SWIG interface instead.
-# This file is compatible with both classic and new-style classes.
 
 import _audio_oss
 
@@ -36,12 +35,17 @@ except AttributeError:
 del types
 
 
-class audio_oss_sink_sptr(_object):
+def _swig_setattr_nondynamic_method(set):
+    def set_attr(self,name,value):
+        if hasattr(self,name) or (name in ("this", "thisown")):
+            set(self,name,value)
+        else:
+            raise AttributeError("You cannot add attributes to %s" % self)
+    return set_attr
+
+
+class audio_oss_sink_sptr(object):
     """Proxy of C++ audio_oss_sink_sptr class"""
-    __swig_setmethods__ = {}
-    __setattr__ = lambda self, name, value: _swig_setattr(self, audio_oss_sink_sptr, name, value)
-    __swig_getmethods__ = {}
-    __getattr__ = lambda self, name: _swig_getattr(self, audio_oss_sink_sptr, name)
     def __repr__(self):
         return "<%s.%s; proxy of C++ boost::shared_ptr<audio_oss_sink > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
@@ -49,45 +53,59 @@ class audio_oss_sink_sptr(_object):
         __init__(self) -> audio_oss_sink_sptr
         __init__(self,  p) -> audio_oss_sink_sptr
         """
-        _swig_setattr(self, audio_oss_sink_sptr, 'this', _audio_oss.new_audio_oss_sink_sptr(*args))
-        _swig_setattr(self, audio_oss_sink_sptr, 'thisown', 1)
-    def __deref__(*args): 
+        newobj = _audio_oss.new_audio_oss_sink_sptr(*args)
+        self.this = newobj.this
+        self.thisown = 1
+        del newobj.thisown
+    def __deref__(*args):
         """__deref__(self)"""
         return _audio_oss.audio_oss_sink_sptr___deref__(*args)
 
-    def name(*args): 
+    def name(*args):
         """name(self) -> string"""
         return _audio_oss.audio_oss_sink_sptr_name(*args)
 
-    def input_signature(*args): 
+    def input_signature(*args):
         """input_signature(self) -> gr_io_signature_sptr"""
         return _audio_oss.audio_oss_sink_sptr_input_signature(*args)
 
-    def output_signature(*args): 
+    def output_signature(*args):
         """output_signature(self) -> gr_io_signature_sptr"""
         return _audio_oss.audio_oss_sink_sptr_output_signature(*args)
 
-    def unique_id(*args): 
+    def unique_id(*args):
         """unique_id(self) -> long"""
         return _audio_oss.audio_oss_sink_sptr_unique_id(*args)
 
-    def output_multiple(*args): 
+    def history(*args):
+        """history(self) -> unsigned int"""
+        return _audio_oss.audio_oss_sink_sptr_history(*args)
+
+    def output_multiple(*args):
         """output_multiple(self) -> int"""
         return _audio_oss.audio_oss_sink_sptr_output_multiple(*args)
 
-    def relative_rate(*args): 
+    def relative_rate(*args):
         """relative_rate(self) -> double"""
         return _audio_oss.audio_oss_sink_sptr_relative_rate(*args)
 
-    def check_topology(*args): 
+    def check_topology(*args):
         """check_topology(self, int ninputs, int noutputs) -> bool"""
         return _audio_oss.audio_oss_sink_sptr_check_topology(*args)
 
-    def detail(*args): 
+    def start(*args):
+        """start(self) -> bool"""
+        return _audio_oss.audio_oss_sink_sptr_start(*args)
+
+    def stop(*args):
+        """stop(self) -> bool"""
+        return _audio_oss.audio_oss_sink_sptr_stop(*args)
+
+    def detail(*args):
         """detail(self) -> gr_block_detail_sptr"""
         return _audio_oss.audio_oss_sink_sptr_detail(*args)
 
-    def set_detail(*args): 
+    def set_detail(*args):
         """set_detail(self, gr_block_detail_sptr detail)"""
         return _audio_oss.audio_oss_sink_sptr_set_detail(*args)
 
@@ -100,9 +118,9 @@ class audio_oss_sink_sptr(_object):
 
 class audio_oss_sink_sptrPtr(audio_oss_sink_sptr):
     def __init__(self, this):
-        _swig_setattr(self, audio_oss_sink_sptr, 'this', this)
-        if not hasattr(self,"thisown"): _swig_setattr(self, audio_oss_sink_sptr, 'thisown', 0)
-        _swig_setattr(self, audio_oss_sink_sptr,self.__class__,audio_oss_sink_sptr)
+        self.this = this
+        if not hasattr(self,"thisown"): self.thisown = 0
+        self.__class__ = audio_oss_sink_sptr
 _audio_oss.audio_oss_sink_sptr_swigregister(audio_oss_sink_sptrPtr)
 
 
@@ -112,12 +130,8 @@ def audio_oss_sink_block(*args):
 audio_oss_sink_sptr.block = lambda self: audio_oss_sink_block (self)
 audio_oss_sink_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())
 
-class audio_oss_source_sptr(_object):
+class audio_oss_source_sptr(object):
     """Proxy of C++ audio_oss_source_sptr class"""
-    __swig_setmethods__ = {}
-    __setattr__ = lambda self, name, value: _swig_setattr(self, audio_oss_source_sptr, name, value)
-    __swig_getmethods__ = {}
-    __getattr__ = lambda self, name: _swig_getattr(self, audio_oss_source_sptr, name)
     def __repr__(self):
         return "<%s.%s; proxy of C++ boost::shared_ptr<audio_oss_source > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
@@ -125,45 +139,59 @@ class audio_oss_source_sptr(_object):
         __init__(self) -> audio_oss_source_sptr
         __init__(self,  p) -> audio_oss_source_sptr
         """
-        _swig_setattr(self, audio_oss_source_sptr, 'this', _audio_oss.new_audio_oss_source_sptr(*args))
-        _swig_setattr(self, audio_oss_source_sptr, 'thisown', 1)
-    def __deref__(*args): 
+        newobj = _audio_oss.new_audio_oss_source_sptr(*args)
+        self.this = newobj.this
+        self.thisown = 1
+        del newobj.thisown
+    def __deref__(*args):
         """__deref__(self)"""
         return _audio_oss.audio_oss_source_sptr___deref__(*args)
 
-    def name(*args): 
+    def name(*args):
         """name(self) -> string"""
         return _audio_oss.audio_oss_source_sptr_name(*args)
 
-    def input_signature(*args): 
+    def input_signature(*args):
         """input_signature(self) -> gr_io_signature_sptr"""
         return _audio_oss.audio_oss_source_sptr_input_signature(*args)
 
-    def output_signature(*args): 
+    def output_signature(*args):
         """output_signature(self) -> gr_io_signature_sptr"""
         return _audio_oss.audio_oss_source_sptr_output_signature(*args)
 
-    def unique_id(*args): 
+    def unique_id(*args):
         """unique_id(self) -> long"""
         return _audio_oss.audio_oss_source_sptr_unique_id(*args)
 
-    def output_multiple(*args): 
+    def history(*args):
+        """history(self) -> unsigned int"""
+        return _audio_oss.audio_oss_source_sptr_history(*args)
+
+    def output_multiple(*args):
         """output_multiple(self) -> int"""
         return _audio_oss.audio_oss_source_sptr_output_multiple(*args)
 
-    def relative_rate(*args): 
+    def relative_rate(*args):
         """relative_rate(self) -> double"""
         return _audio_oss.audio_oss_source_sptr_relative_rate(*args)
 
-    def check_topology(*args): 
+    def check_topology(*args):
         """check_topology(self, int ninputs, int noutputs) -> bool"""
         return _audio_oss.audio_oss_source_sptr_check_topology(*args)
 
-    def detail(*args): 
+    def start(*args):
+        """start(self) -> bool"""
+        return _audio_oss.audio_oss_source_sptr_start(*args)
+
+    def stop(*args):
+        """stop(self) -> bool"""
+        return _audio_oss.audio_oss_source_sptr_stop(*args)
+
+    def detail(*args):
         """detail(self) -> gr_block_detail_sptr"""
         return _audio_oss.audio_oss_source_sptr_detail(*args)
 
-    def set_detail(*args): 
+    def set_detail(*args):
         """set_detail(self, gr_block_detail_sptr detail)"""
         return _audio_oss.audio_oss_source_sptr_set_detail(*args)
 
@@ -176,9 +204,9 @@ class audio_oss_source_sptr(_object):
 
 class audio_oss_source_sptrPtr(audio_oss_source_sptr):
     def __init__(self, this):
-        _swig_setattr(self, audio_oss_source_sptr, 'this', this)
-        if not hasattr(self,"thisown"): _swig_setattr(self, audio_oss_source_sptr, 'thisown', 0)
-        _swig_setattr(self, audio_oss_source_sptr,self.__class__,audio_oss_source_sptr)
+        self.this = this
+        if not hasattr(self,"thisown"): self.thisown = 0
+        self.__class__ = audio_oss_source_sptr
 _audio_oss.audio_oss_source_sptr_swigregister(audio_oss_source_sptrPtr)
 
 def sink(*args):
@@ -196,6 +224,7 @@ audio_oss_source_sptr.block = lambda self: audio_oss_source_block (self)
 audio_oss_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())
 
 
+
 def source(*args):
     """
     source(int sampling_freq, string dev="") -> audio_oss_source_sptr
